==> igniteui-react-charts-16.4.1.tgz: package/ES2015/RangeColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
export class RangeColumnSeries extends HorizontalRangeCategorySeries {
    constructor() {
        super();
        this.ab = RangeColumnSeries.$;
    }
    bf() {
        return new RangeColumnSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.o9 = a;
    }
    get_nm() {
        return true;
    }
    get nm() {
        return this.get_nm();
    }
    preferredCategoryMode(a) {
        return 2;
    }
    ll(a) {
        if (this.xAxis == null || this.yAxis == null) {
            return Rect.empty;
        }
        let b = this.k7(a);
        let c = this.bi.bq;
        let d = this.bi.bp;
        let e = this.getEffectiveViewport1(this.bi);
        let f = new ScalerParams(0, c, d, this.yAxis.b8, e);
        f.b = this.ed();
        let g = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), a, true);
        if (g == null) {
            return Rect.empty;
        }
        let h = g[0];
        let i = g[1];
        let j = Math.abs(b.x - h[0]);
        let k = Math.abs(b.x - i[0]);
        let l = this.xAxis.jk(c, d, e);
        if (j < k) {
            let m = h[0] - 0.5 * l;
            let n = h[1];
            let o = h[2];
            return new Rect(0, m, Math.min(n, o), l, Math.max(n, o) - Math.min(n, o));
        }
        else {
            let p = i[0] - 0.5 * l;
            let q = i[1];
            let r = i[2];
            return new Rect(0, p, Math.min(q, r), l, Math.max(q, r) - Math.min(q, r));
        }
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (a && c.cx != null) {
            c.cx.count = 0;
        }
    }
    ec() {
        return this.xAxis.jk(this.bi.bq, this.bi.bp, this.getEffectiveViewport1(this.bi));
    }
    oe(a, b) {
        super.oe(a, b);
        let c = typeCast(RangeColumnSeriesView.$, b);
        let d = a.f;
        let e = b.bq;
        let f = b.bp;
        let g = this.getEffectiveViewport1(b);
        let h = this.xAxis.jk(e, f, g);
        if (isNaN_(h) || isInfinity(h)) {
            c.cx.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.xAxis, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.pa;
        this.m5.q = this.pb;
        this.m5.j = this.pa;
        this.m5.k = this.pb;
        let i = false;
        let j = this.m5.c;
        if (j != null) {
            i = true;
        }
        let k = this.xAxis.cc;
        let l = this.lowColumn.count;
        let m = this.xAxis;
        let n = new ScalerParams(0, e, f, this.xAxis.b8, g);
        let o = 0;
        for (let p = 0; p < d.count; ++p) {
            let q = d._inner[p][0] - 0.5 * h;
            let r = Math.min(d._inner[p][1], d._inner[p][2]);
            let s = Math.max(d._inner[p][1], d._inner[p][2]);
            let t = Math.abs(s - r);
            if (isInfinity(t)) {
                continue;
            }
            let u = c.cx.item(o);
            o++;
            u.width = h;
            u.height = t;
            if (i) {
                this.oa(d, p, l, m, n, b.n);
            }
            this.m5.ae(u, false, false, false, false);
            u.al = this.m5.j;
            u.am = this.m5.k;
            c.c2(u, q, r);
        }
        c.cx.count = o;
        b.cs(a);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
RangeColumnSeries.$t = markType(RangeColumnSeries, 'RangeColumnSeries', HorizontalRangeCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, RangeColumnSeries, 'raisePropertyChanged', ['RadiusX:pa:pe', [1, 2], 'RadiusY:pb:pf', [1, 2]]);
export class RangeColumnSeriesView extends RangeCategorySeriesView {
    constructor(a) {
        super(a);
        this.cw = null;
        this.cx = null;
        this.cy = null;
        this.c3 = new Rectangle();
        this.cw = a;
        this.cx = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.c4);
            $ret.activate = runOn(this, this.cz);
            $ret.disactivate = runOn(this, this.c1);
            $ret.destroy = runOn(this, this.c0);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.cy = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    }
    c4() {
        let a = new Rectangle();
        this.cy.add(a);
        a._visibility = 1;
        return a;
    }
    cz(a) {
        a._visibility = 0;
    }
    c1(a) {
        a._visibility = 1;
    }
    c0(a) {
        this.cy.remove(a);
    }
    c2(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.cy._inner[a];
    }
    y(a) {
        let b = this.cy._inner[a];
        this.c3._visibility = b._visibility;
        this.c3.n = b.n;
        this.c3.o = b.o;
        this.c3.width = b.width;
        this.c3.height = b.height;
        let c = this.bl(a);
        this.c3._fill = c;
        this.c3._stroke = c;
        this.c3.ac = this.e.eu + 3;
        return this.c3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.cy.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.cx.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
RangeColumnSeriesView.$t = markType(RangeColumnSeriesView, 'RangeColumnSeriesView', RangeCategorySeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.RangeColumnSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.RangeColumnSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/RangeColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, markType, fromEnum } from "igniteui-react-core/ES2015/type";
import { Rect } from "igniteui-react-core/ES2015/Rect";
import { ScalerParams } from "./ScalerParams";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, isInfinity } from "igniteui-react-core/ES2015/number";
import { RangeCategorySeriesView } from "./RangeCategorySeriesView";
export class RangeColumnSeries extends HorizontalRangeCategorySeries {
    constructor() {
        super();
        this.ab = RangeColumnSeries.$;
    }
    bf() {
        return new RangeColumnSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.pa = a;
    }
    get_nm() {
        return true;
    }
    preferredCategoryMode(a) {
        return 2;
    }
    ll(a) {
        if (this.xAxis == null || this.yAxis == null) {
            return Rect.empty;
        }
        let b = this.k7(a);
        let c = this.bi.bs;
        let d = this.bi.br;
        let e = this.getEffectiveViewport1(this.bi);
        let f = new ScalerParams(0, c, d, this.yAxis.b8, e);
        f.b = this.ed();
        let g = this.aj(this.mx(), this.my.f, this.ny(this.bi), this.nz(this.bi), a, true);
        if (g == null) {
            return Rect.empty;
        }
        let h = g[0];
        let i = g[1];
        let j = Math.abs(b.x - h[0]);
        let k = Math.abs(b.x - i[0]);
        let l = this.xAxis.jk(c, d, e);
        if (j < k) {
            let m = h[0] - 0.5 * l;
            let n = h[1];
            let o = h[2];
            return new Rect(0, m, Math.min(n, o), l, Math.max(n, o) - Math.min(n, o));
        }
        else {
            let p = i[0] - 0.5 * l;
            let q = i[1];
            let r = i[2];
            return new Rect(0, p, Math.min(q, r), l, Math.max(q, r) - Math.min(q, r));
        }
    }
    df(a, b) {
        if (this.di(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        if (a && c.cz != null) {
            c.cz.count = 0;
        }
    }
    ec() {
        return this.xAxis.jk(this.bi.bs, this.bi.br, this.getEffectiveViewport1(this.bi));
    }
    of(a, b) {
        super.of(a, b);
        let c = typeCast(RangeColumnSeriesView.$, b);
        let d = a.f;
        let e = b.bs;
        let f = b.br;
        let g = this.getEffectiveViewport1(b);
        let h = this.xAxis.jk(e, f, g);
        if (isNaN_(h) || isInfinity(h)) {
            c.cz.count = 0;
            return;
        }
        this.m5.x(this, this.nq(), this.xAxis, runOn(this, this.mr), this.ny(b), this.nz(b));
        this.m5.p = this.pb;
        this.m5.q = this.pc;
        this.m5.j = this.pb;
        this.m5.k = this.pc;
        let i = false;
        let j = this.m5.c;
        if (j != null) {
            i = true;
        }
        let k = this.xAxis.cc;
        let l = this.lowColumn.count;
        let m = this.xAxis;
        let n = new ScalerParams(0, e, f, this.xAxis.b8, g);
        let o = 0;
        for (let p = 0; p < d.count; ++p) {
            let q = d._inner[p][0] - 0.5 * h;
            let r = Math.min(d._inner[p][1], d._inner[p][2]);
            let s = Math.max(d._inner[p][1], d._inner[p][2]);
            let t = Math.abs(s - r);
            if (isInfinity(t)) {
                continue;
            }
            let u = c.cz.item(o);
            o++;
            u.width = h;
            u.height = t;
            if (i) {
                this.ob(d, p, l, m, n, b.n);
            }
            this.m5.ae(u, false, false, false, false);
            u.al = this.m5.j;
            u.am = this.m5.k;
            c.c4(u, q, r);
        }
        c.cz.count = o;
        b.cu(a);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
RangeColumnSeries.$t = markType(RangeColumnSeries, 'RangeColumnSeries', HorizontalRangeCategorySeries.$);
Type.dep(DependencyProperty, PropertyMetadata, RangeColumnSeries, 'raisePropertyChanged', ['RadiusX:pb:pf', [1, 2], 'RadiusY:pc:pg', [1, 2]]);
export class RangeColumnSeriesView extends RangeCategorySeriesView {
    constructor(a) {
        super(a);
        this.cy = null;
        this.cz = null;
        this.c0 = null;
        this.c5 = new Rectangle();
        this.cy = a;
        this.cz = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.c6);
            $ret.activate = runOn(this, this.c1);
            $ret.disactivate = runOn(this, this.c3);
            $ret.destroy = runOn(this, this.c2);
            return $ret;
        })());
    }
    ap() {
        super.ap();
        this.c0 = new List$1(Rectangle.$, 0);
        if (!this.n) {
            this.e.eq = 4;
            this.e.bj = 1;
        }
    }
    c6() {
        let a = new Rectangle();
        this.c0.add(a);
        a._visibility = 1;
        return a;
    }
    c1(a) {
        a._visibility = 0;
    }
    c3(a) {
        a._visibility = 1;
    }
    c2(a) {
        this.c0.remove(a);
    }
    c4(a, b, c) {
        if (!this.isDirty) {
            this.an();
        }
        a.o = c;
        a.n = b;
    }
    z(a) {
        return this.c0._inner[a];
    }
    y(a) {
        let b = this.c0._inner[a];
        this.c5._visibility = b._visibility;
        this.c5.n = b.n;
        this.c5.o = b.o;
        this.c5.width = b.width;
        this.c5.height = b.height;
        let c = this.bm(a);
        this.c5._fill = c;
        this.c5._stroke = c;
        this.c5.ac = this.e.eu + 3;
        return this.c5;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            for (let c = 0; c < this.c0.count; c++) {
                let d = this.x(c, b);
                this.ba(d, c, b);
                a.v(d);
            }
        }
    }
    ai(a) {
        super.ai(a);
        let b = 0;
        let c = new List$1(Rectangle.$, 0);
        for (let d of fromEnum(this.cz.a)) {
            c.add(d);
        }
        c.aa((e, f) => {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        for (let e of fromEnum(c)) {
            this.e.a2.exportRectangleData(a, e, "column" + b, ["Main", "Fill"]);
        }
        b++;
    }
}
RangeColumnSeriesView.$t = markType(RangeColumnSeriesView, 'RangeColumnSeriesView', RangeCategorySeriesView.$);
